@@ -150,6 +150,8 @@
 #include <explain/syscall/setsid.h>
 #include <explain/syscall/setsockopt.h>
 #include <explain/syscall/setvbuf.h>
+#include <explain/syscall/shmat.h>
+#include <explain/syscall/shmctl.h>
 #include <explain/syscall/signalfd.h>
 #include <explain/syscall/socket.h>
 #include <explain/syscall/socketpair.h>
@@ -528,8 +530,8 @@ static const table_t table[] =
     /* FIXME: add support for setxattr */
     /* FIXME: add support for set_zone_reclaim */
     /* FIXME: add support for sgetmask */
-    /* FIXME: add support for shmat */
-    /* FIXME: add support for shmctl */
+    { "shmat", explain_syscall_shmat },
+    { "shmctl", explain_syscall_shmctl },
     /* FIXME: add support for shmdt */
     /* FIXME: add support for shmget */
     /* FIXME: add support for shutdown */
