@@ -1503,6 +1503,13 @@
 0
 #endif
 },
+{ "HAVE_PTRACE",
+#ifdef HAVE_PTRACE
+1
+#else
+0
+#endif
+},
 { "HAVE_PUTENV",
 #ifdef HAVE_PUTENV
 1
@@ -1573,6 +1580,20 @@
 0
 #endif
 },
+{ "HAVE_SHMAT",
+#ifdef HAVE_SHMAT
+1
+#else
+0
+#endif
+},
+{ "HAVE_SHMCTL",
+#ifdef HAVE_SHMCTL
+1
+#else
+0
+#endif
+},
 { "HAVE_SIGNALFD",
 #ifdef HAVE_SIGNALFD
 1
@@ -1867,6 +1888,13 @@
 0
 #endif
 },
+{ "HAVE_SYS_SHM_H",
+#ifdef HAVE_SYS_SHM_H
+1
+#else
+0
+#endif
+},
 { "HAVE_SYS_SIGNALFD_H",
 #ifdef HAVE_SYS_SIGNALFD_H
 1
@@ -2413,6 +2441,13 @@
 0
 #endif
 },
+{ "SYS_PTRACE_USER_REGS_STRUCT",
+#ifdef SYS_PTRACE_USER_REGS_STRUCT
+1
+#else
+0
+#endif
+},
 { "TIME_WITH_SYS_TIME",
 #ifdef TIME_WITH_SYS_TIME
 1
@@ -2420,6 +2455,20 @@
 0
 #endif
 },
+{ "V4L2_BUF_TYPE_VIDEO_CAPTURE_MPLANE",
+#ifdef V4L2_BUF_TYPE_VIDEO_CAPTURE_MPLANE
+1
+#else
+0
+#endif
+},
+{ "V4L2_BUF_TYPE_VIDEO_OUTPUT_MPLANE",
+#ifdef V4L2_BUF_TYPE_VIDEO_OUTPUT_MPLANE
+1
+#else
+0
+#endif
+},
 { "VA_LIST_VOID_STAR",
 #ifdef VA_LIST_VOID_STAR
 1
